<?php

namespace Pure\Career\Policies;

use Litepie\User\Contracts\UserPolicy;
use Pure\Career\Models\CareerApplication;

class CareerApplicationPolicy
{

    /**
     * Determine if the given user can view the career_application.
     *
     * @param UserPolicy $user
     * @param CareerApplication $career_application
     *
     * @return bool
     */
    public function view(UserPolicy $user, CareerApplication $career_application)
    {
        if ($user->canDo('career.career_application.view') && $user->isAdmin()) {
            return true;
        }

        return $career_application->user_id == user_id() && $career_application->user_type == user_type();
    }

    /**
     * Determine if the given user can create a career_application.
     *
     * @param UserPolicy $user
     * @param CareerApplication $career_application
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('career.career_application.create');
    }

    /**
     * Determine if the given user can update the given career_application.
     *
     * @param UserPolicy $user
     * @param CareerApplication $career_application
     *
     * @return bool
     */
    public function update(UserPolicy $user, CareerApplication $career_application)
    {
        if ($user->canDo('career.career_application.edit') && $user->isAdmin()) {
            return true;
        }

        return $career_application->user_id == user_id() && $career_application->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given career_application.
     *
     * @param UserPolicy $user
     * @param CareerApplication $career_application
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CareerApplication $career_application)
    {
        return $career_application->user_id == user_id() && $career_application->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given career_application.
     *
     * @param UserPolicy $user
     * @param CareerApplication $career_application
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CareerApplication $career_application)
    {
        if ($user->canDo('career.career_application.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given career_application.
     *
     * @param UserPolicy $user
     * @param CareerApplication $career_application
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CareerApplication $career_application)
    {
        if ($user->canDo('career.career_application.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
