<?php

namespace Pure\Career\Policies;

use Litepie\User\Contracts\UserPolicy;
use Pure\Career\Models\CareerCategory;

class CareerCategoryPolicy
{

    /**
     * Determine if the given user can view the career_category.
     *
     * @param UserPolicy $user
     * @param CareerCategory $career_category
     *
     * @return bool
     */
    public function view(UserPolicy $user, CareerCategory $career_category)
    {
        if ($user->canDo('career.career_category.view') && $user->isAdmin()) {
            return true;
        }

        return $career_category->user_id == user_id() && $career_category->user_type == user_type();
    }

    /**
     * Determine if the given user can create a career_category.
     *
     * @param UserPolicy $user
     * @param CareerCategory $career_category
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('career.career_category.create');
    }

    /**
     * Determine if the given user can update the given career_category.
     *
     * @param UserPolicy $user
     * @param CareerCategory $career_category
     *
     * @return bool
     */
    public function update(UserPolicy $user, CareerCategory $career_category)
    {
        if ($user->canDo('career.career_category.edit') && $user->isAdmin()) {
            return true;
        }

        return $career_category->user_id == user_id() && $career_category->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given career_category.
     *
     * @param UserPolicy $user
     * @param CareerCategory $career_category
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CareerCategory $career_category)
    {
        return $career_category->user_id == user_id() && $career_category->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given career_category.
     *
     * @param UserPolicy $user
     * @param CareerCategory $career_category
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CareerCategory $career_category)
    {
        if ($user->canDo('career.career_category.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given career_category.
     *
     * @param UserPolicy $user
     * @param CareerCategory $career_category
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CareerCategory $career_category)
    {
        if ($user->canDo('career.career_category.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
