<?php

namespace Pure\Career\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Pure\Career\Models\Career;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Pure\Career\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/career/career_job/*')) {
            Route::bind('career_job', function ($career_job) {
                $career_jobrepo = $this->app->make('Pure\Career\Interfaces\CareerJobRepositoryInterface');
                return $career_jobrepo->findorNew($career_job);
            });
        }
        if (Request::is('*/career/career_category/*')) {
            Route::bind('career_category', function ($career_category) {
                $career_categoryrepo = $this->app->make('Pure\Career\Interfaces\CareerCategoryRepositoryInterface');
                return $career_categoryrepo->findorNew($career_category);
            });
        }
        if (Request::is('*/career/career_application/*')) {
            Route::bind('career_application', function ($career_application) {
                $career_applicationrepo = $this->app->make('Pure\Career\Interfaces\CareerApplicationRepositoryInterface');
                return $career_applicationrepo->findorNew($career_application);
            });
        }
        if (Request::is('*/career/career_meta/*')) {
            Route::bind('career_meta', function ($career_meta) {
                $career_metarepo = $this->app->make('Pure\Career\Interfaces\CareerMetaRepositoryInterface');
                return $career_metarepo->findorNew($career_meta);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        if(request()->segment(1) != 'api' && request()->segment(2) != 'api') {
            return;
        }

        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale() . '/api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
