<?php

namespace Pure\Career\Providers;

use Litepie\Contracts\Workflow\Workflow as WorkflowContract;
use Litepie\Foundation\Support\Providers\WorkflowServiceProvider as ServiceProvider;

class WorkflowServiceProvider extends ServiceProvider
{
    /**
     * The validators mappings for the package.
     *
     * @var array
     */
    protected $validators = [
        // Bind CareerJob workflow validator
        'Pure\Career\Models\CareerJob' => \Pure\Career\Workflow\CareerJobValidator::class,
        // Bind CareerCategory workflow validator
        'Pure\Career\Models\CareerCategory' => \Pure\Career\Workflow\CareerCategoryValidator::class,
        // Bind CareerApplication workflow validator
        'Pure\Career\Models\CareerApplication' => \Pure\Career\Workflow\CareerApplicationValidator::class,
        // Bind CareerMeta workflow validator
        'Pure\Career\Models\CareerMeta' => \Pure\Career\Workflow\CareerMetaValidator::class,
    ];

    /**
     * The actions mappings for the package.
     *
     * @var array
     */
    protected $actions = [
        // Bind CareerJob workflow actions
        'Pure\Career\Models\CareerJob' => \Pure\Career\Workflow\CareerJobAction::class,
        // Bind CareerCategory workflow actions
        'Pure\Career\Models\CareerCategory' => \Pure\Career\Workflow\CareerCategoryAction::class,
        // Bind CareerApplication workflow actions
        'Pure\Career\Models\CareerApplication' => \Pure\Career\Workflow\CareerApplicationAction::class,
        // Bind CareerMeta workflow actions
        'Pure\Career\Models\CareerMeta' => \Pure\Career\Workflow\CareerMetaAction::class,
    ];

    /**
     * The notifiers mappings for the package.
     *
     * @var array
     */
    protected $notifiers = [
       // Bind CareerJob workflow notifiers
        'Pure\Career\Models\CareerJob' => \Pure\Career\Workflow\CareerJobNotifier::class,
        // Bind CareerCategory workflow notifiers
        'Pure\Career\Models\CareerCategory' => \Pure\Career\Workflow\CareerCategoryNotifier::class,
        // Bind CareerApplication workflow notifiers
        'Pure\Career\Models\CareerApplication' => \Pure\Career\Workflow\CareerApplicationNotifier::class,
        // Bind CareerMeta workflow notifiers
        'Pure\Career\Models\CareerMeta' => \Pure\Career\Workflow\CareerMetaNotifier::class,
    ];

    /**
     * Register any package workflow validation services.
     *
     * @param \Litepie\Contracts\Workflow\Workflow $workflow
     *
     * @return void
     */
    public function boot(WorkflowContract $workflow)
    {
        parent::registerValidators($workflow);
        parent::registerActions($workflow);
        parent::registerNotifiers($workflow);
    }
}
