<?php

namespace Pure\Career\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Pure\Career\Models\CareerApplication;

class CareerApplicationAction
{
    /**
     * Perform the complete action.
     *
     * @param CareerApplication $career_application
     *
     * @return CareerApplication
     */
    public function complete(CareerApplication $career_application)
    {
        try {
            $career_application->status = 'complete';
            return $career_application->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param CareerApplication $career_application
     *
     * @return CareerApplication
     */public function verify(CareerApplication $career_application)
    {
        try {
            $career_application->status = 'verify';
            return $career_application->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param CareerApplication $career_application
     *
     * @return CareerApplication
     */public function approve(CareerApplication $career_application)
    {
        try {
            $career_application->status = 'approve';
            return $career_application->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param CareerApplication $career_application
     *
     * @return CareerApplication
     */public function publish(CareerApplication $career_application)
    {
        try {
            $career_application->status = 'publish';
            return $career_application->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param CareerApplication $career_application
     *
     * @return CareerApplication
     */
    public function archive(CareerApplication $career_application)
    {
        try {
            $career_application->status = 'archive';
            return $career_application->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param CareerApplication $career_application
     *
     * @return CareerApplication
     */
    public function unpublish(CareerApplication $career_application)
    {
        try {
            $career_application->status = 'unpublish';
            return $career_application->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
