<?php

namespace Pure\Career\Workflow;

use Pure\Career\Models\CareerApplication;
use Validator;

class CareerApplicationValidator
{

    /**
     * Determine if the given career_application is valid for complete status.
     *
     * @param CareerApplication $career_application
     *
     * @return bool / Validator
     */
    public function complete(CareerApplication $career_application)
    {
        return Validator::make($career_application->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given career_application is valid for verify status.
     *
     * @param CareerApplication $career_application
     *
     * @return bool / Validator
     */
    public function verify(CareerApplication $career_application)
    {
        return Validator::make($career_application->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given career_application is valid for approve status.
     *
     * @param CareerApplication $career_application
     *
     * @return bool / Validator
     */
    public function approve(CareerApplication $career_application)
    {
        return Validator::make($career_application->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given career_application is valid for publish status.
     *
     * @param CareerApplication $career_application
     *
     * @return bool / Validator
     */
    public function publish(CareerApplication $career_application)
    {
        return Validator::make($career_application->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given career_application is valid for archive status.
     *
     * @param CareerApplication $career_application
     *
     * @return bool / Validator
     */
    public function archive(CareerApplication $career_application)
    {
        return Validator::make($career_application->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given career_application is valid for unpublish status.
     *
     * @param CareerApplication $career_application
     *
     * @return bool / Validator
     */
    public function unpublish(CareerApplication $career_application)
    {
        return Validator::make($career_application->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
