<?php

namespace Pure\Career\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Pure\Career\Models\CareerCategory;

class CareerCategoryAction
{
    /**
     * Perform the complete action.
     *
     * @param CareerCategory $career_category
     *
     * @return CareerCategory
     */
    public function complete(CareerCategory $career_category)
    {
        try {
            $career_category->status = 'complete';
            return $career_category->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param CareerCategory $career_category
     *
     * @return CareerCategory
     */public function verify(CareerCategory $career_category)
    {
        try {
            $career_category->status = 'verify';
            return $career_category->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param CareerCategory $career_category
     *
     * @return CareerCategory
     */public function approve(CareerCategory $career_category)
    {
        try {
            $career_category->status = 'approve';
            return $career_category->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param CareerCategory $career_category
     *
     * @return CareerCategory
     */public function publish(CareerCategory $career_category)
    {
        try {
            $career_category->status = 'publish';
            return $career_category->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param CareerCategory $career_category
     *
     * @return CareerCategory
     */
    public function archive(CareerCategory $career_category)
    {
        try {
            $career_category->status = 'archive';
            return $career_category->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param CareerCategory $career_category
     *
     * @return CareerCategory
     */
    public function unpublish(CareerCategory $career_category)
    {
        try {
            $career_category->status = 'unpublish';
            return $career_category->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
