<?php

namespace Pure\Career\Workflow;

use Pure\Career\Models\CareerCategory;
use Validator;

class CareerCategoryValidator
{

    /**
     * Determine if the given career_category is valid for complete status.
     *
     * @param CareerCategory $career_category
     *
     * @return bool / Validator
     */
    public function complete(CareerCategory $career_category)
    {
        return Validator::make($career_category->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given career_category is valid for verify status.
     *
     * @param CareerCategory $career_category
     *
     * @return bool / Validator
     */
    public function verify(CareerCategory $career_category)
    {
        return Validator::make($career_category->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given career_category is valid for approve status.
     *
     * @param CareerCategory $career_category
     *
     * @return bool / Validator
     */
    public function approve(CareerCategory $career_category)
    {
        return Validator::make($career_category->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given career_category is valid for publish status.
     *
     * @param CareerCategory $career_category
     *
     * @return bool / Validator
     */
    public function publish(CareerCategory $career_category)
    {
        return Validator::make($career_category->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given career_category is valid for archive status.
     *
     * @param CareerCategory $career_category
     *
     * @return bool / Validator
     */
    public function archive(CareerCategory $career_category)
    {
        return Validator::make($career_category->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given career_category is valid for unpublish status.
     *
     * @param CareerCategory $career_category
     *
     * @return bool / Validator
     */
    public function unpublish(CareerCategory $career_category)
    {
        return Validator::make($career_category->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
