<?php

namespace Pure\Career\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Pure\Career\Models\CareerJob;

class CareerJobAction
{
    /**
     * Perform the complete action.
     *
     * @param CareerJob $career_job
     *
     * @return CareerJob
     */
    public function complete(CareerJob $career_job)
    {
        try {
            $career_job->status = 'complete';
            return $career_job->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param CareerJob $career_job
     *
     * @return CareerJob
     */public function verify(CareerJob $career_job)
    {
        try {
            $career_job->status = 'verify';
            return $career_job->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param CareerJob $career_job
     *
     * @return CareerJob
     */public function approve(CareerJob $career_job)
    {
        try {
            $career_job->status = 'approve';
            return $career_job->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param CareerJob $career_job
     *
     * @return CareerJob
     */public function publish(CareerJob $career_job)
    {
        try {
            $career_job->status = 'publish';
            return $career_job->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param CareerJob $career_job
     *
     * @return CareerJob
     */
    public function archive(CareerJob $career_job)
    {
        try {
            $career_job->status = 'archive';
            return $career_job->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param CareerJob $career_job
     *
     * @return CareerJob
     */
    public function unpublish(CareerJob $career_job)
    {
        try {
            $career_job->status = 'unpublish';
            return $career_job->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
