<?php

namespace Pure\Career\Workflow;

use Pure\Career\Models\CareerJob;
use Validator;

class CareerJobValidator
{

    /**
     * Determine if the given career_job is valid for complete status.
     *
     * @param CareerJob $career_job
     *
     * @return bool / Validator
     */
    public function complete(CareerJob $career_job)
    {
        return Validator::make($career_job->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given career_job is valid for verify status.
     *
     * @param CareerJob $career_job
     *
     * @return bool / Validator
     */
    public function verify(CareerJob $career_job)
    {
        return Validator::make($career_job->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given career_job is valid for approve status.
     *
     * @param CareerJob $career_job
     *
     * @return bool / Validator
     */
    public function approve(CareerJob $career_job)
    {
        return Validator::make($career_job->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given career_job is valid for publish status.
     *
     * @param CareerJob $career_job
     *
     * @return bool / Validator
     */
    public function publish(CareerJob $career_job)
    {
        return Validator::make($career_job->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given career_job is valid for archive status.
     *
     * @param CareerJob $career_job
     *
     * @return bool / Validator
     */
    public function archive(CareerJob $career_job)
    {
        return Validator::make($career_job->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given career_job is valid for unpublish status.
     *
     * @param CareerJob $career_job
     *
     * @return bool / Validator
     */
    public function unpublish(CareerJob $career_job)
    {
        return Validator::make($career_job->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
