<?php

namespace Pure\Career\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Pure\Career\Models\CareerMeta;

class CareerMetaAction
{
    /**
     * Perform the complete action.
     *
     * @param CareerMeta $career_meta
     *
     * @return CareerMeta
     */
    public function complete(CareerMeta $career_meta)
    {
        try {
            $career_meta->status = 'complete';
            return $career_meta->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param CareerMeta $career_meta
     *
     * @return CareerMeta
     */public function verify(CareerMeta $career_meta)
    {
        try {
            $career_meta->status = 'verify';
            return $career_meta->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param CareerMeta $career_meta
     *
     * @return CareerMeta
     */public function approve(CareerMeta $career_meta)
    {
        try {
            $career_meta->status = 'approve';
            return $career_meta->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param CareerMeta $career_meta
     *
     * @return CareerMeta
     */public function publish(CareerMeta $career_meta)
    {
        try {
            $career_meta->status = 'publish';
            return $career_meta->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param CareerMeta $career_meta
     *
     * @return CareerMeta
     */
    public function archive(CareerMeta $career_meta)
    {
        try {
            $career_meta->status = 'archive';
            return $career_meta->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param CareerMeta $career_meta
     *
     * @return CareerMeta
     */
    public function unpublish(CareerMeta $career_meta)
    {
        try {
            $career_meta->status = 'unpublish';
            return $career_meta->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
