<?php

namespace Pure\Career\Workflow;

use Pure\Career\Models\CareerMeta;
use Validator;

class CareerMetaValidator
{

    /**
     * Determine if the given career_meta is valid for complete status.
     *
     * @param CareerMeta $career_meta
     *
     * @return bool / Validator
     */
    public function complete(CareerMeta $career_meta)
    {
        return Validator::make($career_meta->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given career_meta is valid for verify status.
     *
     * @param CareerMeta $career_meta
     *
     * @return bool / Validator
     */
    public function verify(CareerMeta $career_meta)
    {
        return Validator::make($career_meta->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given career_meta is valid for approve status.
     *
     * @param CareerMeta $career_meta
     *
     * @return bool / Validator
     */
    public function approve(CareerMeta $career_meta)
    {
        return Validator::make($career_meta->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given career_meta is valid for publish status.
     *
     * @param CareerMeta $career_meta
     *
     * @return bool / Validator
     */
    public function publish(CareerMeta $career_meta)
    {
        return Validator::make($career_meta->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given career_meta is valid for archive status.
     *
     * @param CareerMeta $career_meta
     *
     * @return bool / Validator
     */
    public function archive(CareerMeta $career_meta)
    {
        return Validator::make($career_meta->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given career_meta is valid for unpublish status.
     *
     * @param CareerMeta $career_meta
     *
     * @return bool / Validator
     */
    public function unpublish(CareerMeta $career_meta)
    {
        return Validator::make($career_meta->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
